@@ -2,9 +2,11 @@
 
 from .exception import PyVLXException
 from .lightening_device import Light, LighteningDevice
+from .log import PYVLXLOG
 from .nodes import Nodes
 from .opening_device import (
-    Blade, Blind, GarageDoor, Gate, OpeningDevice, RollerShutter, Window, Awning)
+    Awning, Blade, Blind, GarageDoor, Gate, OpeningDevice, RollerShutter,
+    Window)
 from .parameter import (
     CurrentIntensity, CurrentPosition, Intensity, Parameter, Position,
     SwitchParameter, SwitchParameterOff, SwitchParameterOn, UnknownIntensity,
@@ -13,3 +15,4 @@ from .parameter import (
 from .pyvlx import PyVLX
 from .scene import Scene
 from .scenes import Scenes
+from .klf200gateway import Klf200Gateway
