@@ -5,8 +5,8 @@ Node object is an interface class and should
 be derived by other objects like window openers
 and roller shutters.
 """
+from .api import SetNodeName
 from .exception import PyVLXException
-from .set_node_name import SetNodeName
 
 
 class Node:
@@ -44,16 +44,17 @@ class Node:
 
     def __str__(self):
         """Return object as readable string."""
-        return '<{} name="{}" ' \
-            'node_id="{}" ' \
-            'serial_number="{}"/>' \
-            .format(
-                type(self).__name__,
-                self.name,
-                self.node_id,
-                self.serial_number)
+        return (
+            '<{} name="{}" '
+            'node_id="{}" '
+            'serial_number="{}"/>'.format(
+                type(self).__name__, self.name, self.node_id, self.serial_number
+            )
+        )
 
     def __eq__(self, other):
         """Equal operator."""
-        return type(self).__name__ == type(other).__name__ and \
-            self.__dict__ == other.__dict__
+        return (
+            type(self).__name__ == type(other).__name__
+            and self.__dict__ == other.__dict__
+        )
