@@ -1,5 +1,5 @@
 """Module for scene."""
-from .activate_scene import ActivateScene
+from .api import ActivateScene
 from .exception import PyVLXException
 
 
@@ -31,18 +31,17 @@ class Scene:
         activate_scene = ActivateScene(
             pyvlx=self.pyvlx,
             wait_for_completion=wait_for_completion,
-            scene_id=self.scene_id)
+            scene_id=self.scene_id,
+        )
         await activate_scene.do_api_call()
         if not activate_scene.success:
             raise PyVLXException("Unable to activate scene")
 
     def __str__(self):
         """Return object as readable string."""
-        return '<Scene name="{0}" ' \
-            'id="{1}" />' \
-            .format(
-                self.name,
-                self.scene_id)
+        return '<{} name="{}" id="{}"/>'.format(
+            type(self).__name__, self.name, self.scene_id
+        )
 
     def __eq__(self, other):
         """Equal operator."""
